"""This module contains a mapping of pollutant for each country."""

POLLUTANT_CODE_MAPPING: dict[str, list[str]] = {
    "uaqi": ["co", "no2", "o3", "pm10", "pm25", "so2"],
    "and_aire": ["o3", "pm10", "pm25", "no2", "so2", "co"],
    "aus_combined": ["co", "no2", "o3", "so2", "pm10", "pm25"],
    "aus_nsw": ["co", "no2", "o3", "so2", "pm10", "pm25"],
    "aut_umwelt": ["o3", "pm10", "no2", "so2", "co"],
    "aut_vienna": ["o3", "pm10", "no2", "so2", "co"],
    "bel_irceline": ["pm25", "no2", "o3", "pm10"],
    "bgd_case": ["co", "no2", "o3", "so2", "pm10", "pm25"],
    "bgr_niggg": ["so2", "no2", "pm10", "co", "o3"],
    "bra_saopaulo": ["co", "no2", "o3", "so2", "pm10", "pm25"],
    "can_ec": ["no2", "o3", "pm25", "pm10"],
    "caqi": ["no2", "o3", "co", "so2", "pm10", "pm25"],
    "che_cerclair": ["pm10", "o3", "no2"],
    "chn_mep": ["so2", "no2", "co", "o3", "pm10", "pm25"],
    "chn_mep_1h": ["so2", "no2", "co", "o3", "pm10", "pm25"],
    "col_rmcab": ["o3", "pm25", "pm10", "co", "so2", "no2"],
    "cri_icca": ["co", "no2", "o3", "so2", "pm10", "pm25"],
    "cyp_dli": ["so2", "no2", "co", "o3", "pm10", "pm25", "c6h6"],
    "cze_chmi": ["no2", "o3", "so2", "pm10"],
    "deu_lubw": ["no2", "so2", "co", "o3", "pm10"],
    "deu_uba": ["no2", "o3", "pm10"],
    "dnk_aarhus": ["no2", "co", "o3"],
    "eaqi": ["no2", "o3", "so2", "pm10", "pm25"],
    "ecu_quitoambiente": ["co", "o3", "no2", "so2", "pm25", "pm10"],
    "esp_madrid": ["pm10", "co", "no2", "so2", "o3"],
    "esp_miteco": ["pm10", "pm25", "no2", "so2", "o3"],
    "est_ekuk": ["so2", "no2", "co", "o3", "pm10", "pm25", "nh3", "c6h6"],
    "fin_hsy": ["so2", "no2", "pm10", "pm25", "o3", "co", "trs"],
    "fra_atmo": ["so2", "no2", "o3", "pm25", "pm10"],
    "gbr_defra": ["no2", "o3", "so2", "pm25", "pm10"],
    "gib_gea": ["o3", "no2", "so2", "co", "pm10", "pm25"],
    "hkg_epd": ["so2", "no2", "o3", "pm25", "pm10"],
    "hrv_azo": ["no2", "o3", "co", "so2", "pm10", "pm25"],
    "hun_bler": ["no2", "pm10", "so2", "o3", "co"],
    "idn_menlhk": ["o3", "pm10", "co", "so2", "no2"],
    "ind_cpcb": ["pm10", "pm25", "no2", "o3", "co", "so2", "nh3"],
    "irl_epa": ["o3", "no2", "so2", "pm25", "pm10"],
    "isr_moep": ["o3", "so2", "no2", "nox", "co", "pm10", "pm25"],
    "ita_moniqa": ["co", "no2", "o3", "so2", "pm10", "pm25"],
    "jpn_aeros": ["so2", "no", "no2", "o3", "nmhc", "pm10", "pm25"],
    "kor_airkorea": ["pm25", "pm10", "so2", "co", "o3", "no2"],
    "kwt_beatona": ["co", "o3", "no2", "so2", "pm10"],
    "lie_cerclair": ["pm10", "o3", "no2"],
    "ltu_gamta": ["o3", "pm10", "no2", "so2", "co"],
    "lux_emwelt": ["o3", "no2", "no", "co", "so2", "pm10"],
    "mex_cdmx": ["so2", "no2", "pm10", "pm25", "o3", "co"],
    "mex_gto": ["so2", "no2", "pm10", "pm25", "o3", "co"],
    "mex_icars": ["pm25", "pm10", "so2", "co", "o3", "no2"],
    "mkd_moepp": ["no2", "o3", "co", "so2", "pm10", "pm25"],
    "mng_eic": ["o3", "pm10", "pm25", "co", "so2", "no2"],
    "mng_ubgov": ["co", "no2", "o3", "so2", "pm10", "pm25"],
    "mys_doe": ["co", "no2", "o3", "so2", "pm25", "pm10"],
    "nld_rivm": ["no2", "pm10", "pm25", "o3"],
    "nor_nilu": ["pm10", "pm25", "no2", "so2", "o3"],
    "npl_doenv": ["pm10", "pm25", "no2", "o3", "co", "so2"],
    "nzl_lawa": ["pm10", "pm25", "no2", "so2", "o3", "co"],
    "per_infoaire": ["o3", "pm10", "pm25", "no2", "so2", "co"],
    "phl_emb": ["o3", "pm10", "pm25", "co", "so2", "no2"],
    "pol_gios": ["pm10", "pm25", "o3", "no2", "so2", "c6h6", "co"],
    "prt_qualar": ["pm10", "pm25", "no2", "o3", "so2"],
    "rou_calitateaer": ["o3", "pm10", "no2", "so2", "co"],
    "sgp_nea": ["pm25", "pm10", "so2", "co", "o3", "no2"],
    "srb_sepa": ["so2", "no2", "pm10", "pm25", "co", "o3"],
    "svk_shmu": ["pm10", "pm25", "co", "no2", "so2", "o3"],
    "tha_pcd": ["co", "no2", "o3", "so2", "pm10", "pm25"],
    "tur_havaizleme": ["pm10", "no2", "o3", "co", "so2"],
    "twn_epa": ["o3", "pm10", "pm25", "co", "so2", "no2"],
    "usa_epa": ["o3", "pm10", "pm25", "co", "so2", "no2"],
    "usa_epa_nowcast": ["o3", "pm10", "pm25", "co", "so2", "no2"],
    "vnm_vea": ["o3", "co", "so2", "no2", "pm10", "pm25"],
}
